=== modified file 'debian/changelog'
--- debian/changelog	2017-01-19 13:49:43 +0000
+++ debian/changelog	2017-01-19 13:52:32 +0000
@@ -2,6 +2,7 @@
 
   * unity::util - add GObject shared memory utility classes
     and helper methods.
+  * unity::util - add Glib memory management utility functions.
 
  -- Pete <pete.woods@canonical.com>  Wed, 11 Jan 2017 16:07:23 +0000
 

=== added file 'include/unity/util/GlibMemory.h'
--- include/unity/util/GlibMemory.h	1970-01-01 00:00:00 +0000
+++ include/unity/util/GlibMemory.h	2017-01-19 13:52:32 +0000
@@ -0,0 +1,58 @@
+/*
+ * Copyright (C) 2017 Canonical Ltd.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Pete Woods <pete.woods@canonical.com>
+ */
+
+#ifndef UNITY_UTIL_GLIBMEMORY_H
+#define UNITY_UTIL_GLIBMEMORY_H
+
+#include <memory>
+#include <glib.h>
+
+namespace unity
+{
+
+namespace util
+{
+
+#pragma push_macro("G_DEFINE_AUTOPTR_CLEANUP_FUNC")
+#undef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+#define G_DEFINE_AUTOPTR_CLEANUP_FUNC(TypeName, func) \
+inline std::shared_ptr<TypeName> share_glib(TypeName* ptr) \
+{ \
+    return std::shared_ptr<TypeName>(ptr, &func); \
+} \
+inline std::unique_ptr<TypeName, decltype(&func)> unique_glib(TypeName* ptr) \
+{ \
+    return std::unique_ptr<TypeName, decltype(&func)>(ptr, &func); \
+}
+
+#pragma push_macro("G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC")
+#undef G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC
+#define G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC(TypeName, func)
+
+#define __GLIB_H_INSIDE__
+#include <glib/glib-autocleanups.h>
+#undef __GLIB_H_INSIDE__
+
+#pragma pop_macro("G_DEFINE_AUTOPTR_CLEANUP_FUNC")
+#pragma pop_macro("G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC")
+
+}  // namespace until
+
+}  // namespace unity
+
+#endif

=== modified file 'test/gtest/unity/util/CMakeLists.txt'
--- test/gtest/unity/util/CMakeLists.txt	2017-01-19 13:49:43 +0000
+++ test/gtest/unity/util/CMakeLists.txt	2017-01-19 13:52:32 +0000
@@ -1,6 +1,7 @@
 add_subdirectory(Daemon)
 add_subdirectory(DefinesPtrs)
 add_subdirectory(FileIO)
+add_subdirectory(GlibMemory)
 add_subdirectory(GObjectMemory)
 add_subdirectory(IniParser)
 add_subdirectory(ResourcePtr)

=== added directory 'test/gtest/unity/util/GlibMemory'
=== added file 'test/gtest/unity/util/GlibMemory/CMakeLists.txt'
--- test/gtest/unity/util/GlibMemory/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ test/gtest/unity/util/GlibMemory/CMakeLists.txt	2017-01-19 13:52:32 +0000
@@ -0,0 +1,12 @@
+include_directories(${GLIB_INCLUDE_DIRS})
+
+add_executable(GlibMemory_test
+    GlibMemory_test.cpp
+    )
+
+target_link_libraries(GlibMemory_test
+    ${TESTLIBS}
+    ${GLIB_LDFLAGS}
+    )
+
+add_test(GlibMemory_test GlibMemory_test)

=== added file 'test/gtest/unity/util/GlibMemory/GlibMemory_test.cpp'
--- test/gtest/unity/util/GlibMemory/GlibMemory_test.cpp	1970-01-01 00:00:00 +0000
+++ test/gtest/unity/util/GlibMemory/GlibMemory_test.cpp	2017-01-19 13:52:32 +0000
@@ -0,0 +1,107 @@
+/*
+ * Copyright (C) 2017 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Pete Woods <pete.woods@canonical.com>
+ */
+
+#include <unity/util/GlibMemory.h>
+
+#include <gtest/gtest.h>
+#include <iostream>
+#include <set>
+#include <string>
+
+using namespace std;
+using namespace unity;
+using namespace unity::util;
+
+namespace
+{
+
+static set<string> keys;
+
+static set<string> values;
+
+class GlibMemoryTest: public testing::Test
+{
+protected:
+    void SetUp() override
+    {
+        keys.clear();
+        values.clear();
+    }
+
+    static void deleteKey(gpointer data)
+    {
+        // Note that we don't g_free the data, because it's a reference to a static string
+        keys.emplace(string((gchar*) data));
+    }
+
+    static void deleteValue(gpointer data)
+    {
+        // Note that we don't g_free the data, because it's a reference to a static string
+        values.emplace(string((gchar*) data));
+    }
+};
+
+TEST_F(GlibMemoryTest, Unique)
+{
+    {
+        auto gkf = unique_glib(g_key_file_new());
+        g_key_file_set_boolean(gkf.get(), "group", "key", TRUE);
+        EXPECT_EQ(TRUE, g_key_file_get_boolean(gkf.get(), "group", "key", NULL));
+    }
+
+    {
+        auto variant = unique_glib(g_variant_new_string("hello"));
+        EXPECT_STREQ("hello", g_variant_get_string(variant.get(), NULL));
+    }
+
+    {
+        {
+            auto hash = unique_glib(g_hash_table_new_full(g_str_hash, g_str_equal, deleteKey, deleteValue));
+            g_hash_table_insert(hash.get(), (gpointer) "hello", (gpointer) "there");
+            g_hash_table_insert(hash.get(), (gpointer) "hash", (gpointer) "world");
+        }
+        EXPECT_EQ(set<string>({"hello", "hash"}), keys);
+        EXPECT_EQ(set<string>({"there", "world"}), values);
+    }
+}
+
+TEST_F(GlibMemoryTest, Share)
+{
+    {
+        auto gkf = share_glib(g_key_file_new());
+        g_key_file_set_boolean(gkf.get(), "group", "key", TRUE);
+        EXPECT_EQ(TRUE, g_key_file_get_boolean(gkf.get(), "group", "key", NULL));
+    }
+
+    {
+        auto variant = share_glib(g_variant_new_string("hello"));
+        EXPECT_STREQ("hello", g_variant_get_string(variant.get(), NULL));
+    }
+
+    {
+        {
+            auto hash = share_glib(g_hash_table_new_full(g_str_hash, g_str_equal, deleteKey, deleteValue));
+            g_hash_table_insert(hash.get(), (gpointer) "hello", (gpointer) "there");
+            g_hash_table_insert(hash.get(), (gpointer) "hash", (gpointer) "world");
+        }
+        EXPECT_EQ(set<string>({"hello", "hash"}), keys);
+        EXPECT_EQ(set<string>({"there", "world"}), values);
+    }
+}
+
+}

=== modified file 'test/headers/CMakeLists.txt'
--- test/headers/CMakeLists.txt	2017-01-19 13:49:43 +0000
+++ test/headers/CMakeLists.txt	2017-01-19 13:52:32 +0000
@@ -11,6 +11,7 @@
 )
 
 set(exclusions
+    "GlibMemory.h"
     "GObjectMemory.h"
 )
 

=== modified file 'test/headers/includechecker.py'
--- test/headers/includechecker.py	2017-01-19 13:49:43 +0000
+++ test/headers/includechecker.py	2017-01-19 13:52:32 +0000
@@ -37,6 +37,7 @@
 allowed = {
     'unity/shell': { 'Qt' }, # Anything under unity/shell can include anything starting with Qt
     'unity/util/GObjectMemory': { 'glib' }, # The unity/util/GObjectMemory header can include anything starting with glib
+    'unity/util/GlibMemory': { 'glib' }, # The unity/util/GlibMemory header can include anything starting with glib
 }
 
 def check_file(filename, permitted_includes):

